/* 
 * Core Interface for mks32 			
 *
 * Copyright (C) Rainer Link, 2001-2002
 *                            OpenAntiVirus.org <rainer@openantivirus.org>
 *		 Krzysztof Drewicz <hunter@pld.org.pl>, 2002
 *
 * Credits to W. Richard Stevens - RIP
 * 
 * This software is licensed under the GNU General Public License (GPL)
 * See: http://www.gnu.org/copyleft/gpl.html
 *
*/

#include <includes.h>
#include "vscan-mksd_core.h"

extern BOOL verbose_file_logging;

 

/* print a message via syslog */
void vscan_syslog(char *printMessage, ...)
{
        char printMsg[512];

        va_list argptr;
        va_start(argptr, printMessage);
        vsnprintf(printMsg, sizeof(printMsg)-1, printMessage, argptr);
        va_end(argptr);

	syslog(SYSLOG_PRIORITY, "%s", printMsg);
}



/* initialise socket to mks32
   returns -1 on error or the socket descriptor */
int vscan_mksd_init(void)
{
	return 0;
}


void vscan_mksd_syslog_alert(char *syslogMessage, ...)
{
        char logMsg[512];

        va_list argptr;
        va_start(argptr, syslogMessage);
        vsnprintf(logMsg, sizeof(logMsg)-1, syslogMessage, argptr);
        va_end(argptr);

        syslog(SYSLOG_PRIORITY_ALERT, "%s\n", logMsg);
}


/*
  If virus is found, logs the filename/virusname into syslog
*/
void vscan_mksd_log_virus(char *infected_file, char *result, char* client_ip)
{
        vscan_syslog_alert("ALERT - Scan result: '%s' infected with virus '%s', client: '%s'", infected_file, result, client_ip);
        
}



/*
  Scans a file (*FILE*, not a directory - keep that in mind) for a virus
  Expects socket descriptor and file name to scan for
  Return -1 on error, 0 if no virus was found, 1 if a virus was found 
*/
int vscan_mksd_scanfile(int sockfd, char *scan_file, char* client_ip)
{
	char recv[MAXBUFF];
	int result,len;

	bzero(recv,sizeof recv);

	if ( verbose_file_logging )
	        vscan_syslog("Scanning file : '%s'", scan_file);

	/* what happens if scan_file is very large? */
	result = mksc_check_filename (scan_file, recv);
	vscan_syslog("%s", recv+4);

	if ( result==1 ) {
		/* virus found */
		vscan_mksd_log_virus(scan_file, recv, client_ip);
		return 1;
	}  	else if ( result==127  ) {
		/* ERROR */
		if ( verbose_file_logging )
			vscan_syslog("ERROR: file %s not found or not readable or deamon not running", scan_file);
	} else if (  result == 0 ) {
		/* OK */
		if ( verbose_file_logging )
			vscan_syslog("file %s is clean (%s)", scan_file, recv);
        } else {
		/* unknown response */
		vscan_syslog("ERROR: unknown response from mksd while scanning %s! (%s)", scan_file,recv);
	}	

	return 0;
	
}

/*
  close socket
*/
void vscan_mksd_end(int sockfd)
{
}
